@@ -149,6 +149,7 @@ class NestedManifest(Model):
     groundtruth_uri = URLType(required=False)
     groundtruth = StringType(required=False)
 
+
     def validate_groundtruth(self, data, value):
         if data.get('groundtruth_uri') and data.get('groundtruth'):
             raise ValidationError("Specify only groundtruth_uri or groundtruth, not both.")
@@ -166,6 +167,7 @@ class Manifest(Model):
     job_api_key = UUIDType(default=uuid.uuid4)
     job_id = UUIDType(default=uuid.uuid4)
     job_total_tasks = IntType(required=True)
+    network = StringType(required=False)
 
     requester_restricted_answer_set = DictType(DictType(StringType))
 
@@ -237,6 +239,9 @@ class Manifest(Model):
     groundtruth_uri = URLType(required=False)
     groundtruth = StringType(required=False)
 
+    rejected_uri = URLType(required=False)
+    rejected_count = IntType(default=0, required=False)
+
     def validate_groundtruth(self, data, value):
         if data.get('groundtruth_uri') and data.get('groundtruth'):
             raise ValidationError("Specify only groundtruth_uri or groundtruth, not both.")
